@@ -1,7 +1,7 @@
 ##----------------------------------------------------------------------------
 ## Markdown Parser Only - ~/lib/Markdown/Parser.pm
-## Version v0.2.0
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.2.1
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/08/23
 ## Modified 2022/09/19
@@ -16,7 +16,7 @@ BEGIN
     use strict;
     use warnings;
     use parent qw( Module::Generic );
-    use vars qw( $ELEMENTS_DICTIONARY $ELEMENTS_DICTIONARY_EXTENDED $VERSION );
+    use vars qw( $ELEMENTS_DICTIONARY $ELEMENTS_DICTIONARY_EXTENDED $VERSION $DEBUG );
     use HTML::TreeBuilder;
     use POSIX ();
     use Regexp::Common qw( Markdown );
@@ -24,7 +24,8 @@ BEGIN
     use CSS::Object;
     use Scalar::Util ();
     use Devel::Confess;
-    our $VERSION = 'v0.2.0';
+    our $DEBUG = 0;
+    our $VERSION = 'v0.2.1';
     # Including vertical space like new lines
     our $ELEMENTS_DICTIONARY =
     {
@@ -50,7 +51,8 @@ sub init
     $self->{charset}                        = 'utf8';
     $self->{code_highlight}                 = 0;
     $self->{css_grid}                       = 0;
-    ## See Markdown::Parser::Link
+    $self->{debug}                          = $DEBUG;
+    # See Markdown::Parser::Link
     $self->{default_email}                  = '';
     $self->{document}                       = '';
     $self->{email_obfuscate_class}          = 'courriel';
@@ -283,7 +285,8 @@ sub parse
             $data =~ s{$RE{Markdown}{Html}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 # my $html = $+{tag_all};
                 # We save exactly what we caught
                 my $html = substr( $data, $-[0], $+[0] - $-[0] );
@@ -305,13 +308,14 @@ sub parse
             {
                 my $re = { %- };
                 $re->{capture} = substr( $data, $-[0], $+[0] - $-[0] );
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $code_def = $+{code_attr};
                 my $code_class = $+{code_class};
                 my $raw = $+{code_all};
                 my $content = $+{code_content};
                 
-                ## Restore any html that got caught previously
+                # Restore any html that got caught previously
                 $content =~ s{\!{2}HTML\[(?<obj_id>\d+)\]\!{2}}
                 {
                     my $obj_id = $+{obj_id};
@@ -348,12 +352,13 @@ sub parse
             $data =~ s{$RE{Markdown}{CodeBlock}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $raw = $+{code_all};
                 my $content = $+{code_content};
-                ## my $new_lines = $+{code_trailing_new_line};
+                # my $new_lines = $+{code_trailing_new_line};
                 
-                ## Restore any html that got caught previously
+                # Restore any html that got caught previously
                 $content =~ s{\!{2}HTML\[(?<obj_id>\d+)\]\!{2}}
                 {
                     my $obj_id = $+{obj_id};
@@ -388,7 +393,8 @@ sub parse
             $data =~ s{$RE{Markdown}{CodeLine}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $raw = $+{code_all};
                 my $content = $+{code_all};
                 
@@ -407,9 +413,9 @@ sub parse
                     }
                 }xgems;
         
-                ## trim leading newlines
+                # trim leading newlines
                 $content =~ s/\A\n+//;
-                ## trim trailing whitespace
+                # trim trailing whitespace
                 $content =~ s/\s+\z//;
                 my $trailing_nl = $self->_total_trailing_new_lines( $raw );
                 my $code = $top->create_code({
@@ -423,7 +429,7 @@ sub parse
                     pos => $pos,
                 }) ) || return( $self->pass_error( $code->error ) );
                 my $id = $top->add_object( $code );
-                ## Move back before the trailing new lines as they may be important for the next check
+                # Move back before the trailing new lines as they may be important for the next check
                 "${PH_PREFIX}${id}${PH_SUFFIX}\n";
             }xgems;
         }
@@ -451,13 +457,14 @@ sub parse
             $data =~ s{$RE{Markdown}{CodeSpan}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $raw = $+{code_all};
                 my $content = $+{code_content};
                 $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found an inline code '$raw' at pos '$pos' with content:\n'{green}" . $content . "{/}' and with capture: " . $self->dump( $re ), return => 1 } ) );
-                ## leading whitespace
+                # leading whitespace
                 $content =~ s/^[ \t]*//g;
-                ## trailing whitespace
+                # trailing whitespace
                 $content =~ s/[ \t]*$//g;
                 my $code = $top->create_code({
                     inline => 1,
@@ -516,7 +523,7 @@ sub parse
                 title => $title,
                 url => $url,
             });
-            ## Just register the link definition, but do not add it to the document
+            # Just register the link definition, but do not add it to the document
             $top->register_link_definition( $lnk );
             '';
         }gme;
@@ -571,16 +578,17 @@ sub parse
             $data =~ s{$RE{Markdown}{ExtFootnoteReference}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $id = $+{footnote_id};
                 my $text = $+{footnote_text};
                 my $footnote;
-                ## Auto-generated id for inline footnote
-                ## Example:
-                ## I met Jack [^](Co-founder of Angels, Inc) at the meet-up.
-                ## Here is an inline note.^[Inlines notes are easier to write]
-                ## Inline footnote, i.e. text provided
-                ## We cannot just do if( !$id ) because a valid id could be '0'
+                # Auto-generated id for inline footnote
+                # Example:
+                # I met Jack [^](Co-founder of Angels, Inc) at the meet-up.
+                # Here is an inline note.^[Inlines notes are easier to write]
+                # Inline footnote, i.e. text provided
+                # We cannot just do if( !$id ) because a valid id could be '0'
                 my $object_id;
                 if( !length( $id ) )
                 {
@@ -598,7 +606,7 @@ sub parse
                     });
                     $top->register_footnote( $footnote );
                 }
-                ## Cannot find an id matching this footnote, so we just add this footnote reference as a text
+                # Cannot find an id matching this footnote, so we just add this footnote reference as a text
                 elsif( !( $footnote = $self->document->get_footnote( $id ) ) )
                 {
                     warn( "Unable to find a matching footnote with the footnote id \"$id\".\nAvailable footnotes ids are: '", $self->document->footnotes->map(sub{ $_->id })->join( "', '" ), "'." );
@@ -611,8 +619,8 @@ sub parse
                 
                 if( $footnote )
                 {
-                    ## Create a footnote reference and associate this footnote id with this reference
-                    ## The footnote reference id will be set by add_reference()
+                    # Create a footnote reference and associate this footnote id with this reference
+                    # The footnote reference id will be set by add_reference()
                     my $ref = $top->create_footnote_ref({
                         footnote => $footnote,
                         raw => $+{footnote_all},
@@ -660,7 +668,8 @@ sub parse
             {
                 my $re = { %- };
                 $re->{capture} = substr( $data, $-[0], $+[0] - $-[0] );
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $code_def = $+{code_attr};
                 my $code_class = $+{code_class};
                 my $raw = $+{code_all};
@@ -691,10 +700,11 @@ sub parse
             $data =~ s{$RE{Markdown}{CodeBlock}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $raw = $+{code_all};
                 my $content = $+{code_content};
-                ## my $new_lines = $+{code_trailing_new_line};
+                # my $new_lines = $+{code_trailing_new_line};
                 my $code = $top->create_code({
                     pos => $pos,
                     raw => $raw,
@@ -715,12 +725,13 @@ sub parse
             $data =~ s{$RE{Markdown}{CodeLine}}
             {
                 my $re = { %- };
-                my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+                # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+                my $pos = pos( $data );
                 my $raw = $+{code_all};
                 my $content = $+{code_all};
-                ## trim leading newlines
+                # trim leading newlines
                 $content =~ s/\A\n+//;
-                ## trim trailing whitespace
+                # trim trailing whitespace
                 $content =~ s/\s+\z//;
                 my $trailing_nl = $self->_total_trailing_new_lines( $raw );
                 my $code = $top->create_code({
@@ -734,7 +745,7 @@ sub parse
                     pos => $pos,
                 }) ) || return( $self->pass_error( $code->error ) );
                 my $id = $self->document->add_object( $code );
-                ## Move back before the trailing new lines as they may be important for the next check
+                # Move back before the trailing new lines as they may be important for the next check
                 "${PH_PREFIX}${id}${PH_SUFFIX}\n";
             }xgems;
         }
@@ -746,10 +757,11 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtTable}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $tbl = $self->parse_table( $re, { doc => $top } );
             my $id = $tbl->object_id;
-            ## pos( $data ) = $pos + length( $+{table} );
+            # pos( $data ) = $pos + length( $+{table} );
             "${PH_PREFIX}${id}${PH_SUFFIX}\n";
         }xgems;
     }
@@ -761,7 +773,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Html}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $html = $+{tag_all};
             $html =~ s{$RE{Markdown}{ExtHtmlMarkdown}}
             {
@@ -802,7 +815,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Blockquote}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found a blockquote '{green}" . $+{bquote_all} . "{/}' at pos '$pos' with capture: " . $self->dump( $re ), return => 1 } ) );
             my $raw = $+{bquote_all};
             my $bq = $raw;
@@ -834,7 +848,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtHeader}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found an extended header '{green}" . $+{header_all} . "{/}' with header level '{green}" . length( $+{header_level} ) . "{/}' and attributes '{green}" . $+{header_attr} . "{/}' at pos '$pos' with capture: " . $self->dump( $re ), return => 1 } ) );
             my $text = $+{header_content};
             my $attr = $+{header_attr};
@@ -843,8 +858,8 @@ sub parse
                 pos => $pos,
                 raw => $+{header_all},
             });
-            ## Further process the text capture
-            ## If there are any elements, they will be placed inside the header element as children
+            # Further process the text capture
+            # If there are any elements, they will be placed inside the header element as children
             my $id = $self->document->add_object( $header );
             $self->parse( $text, { scope => 'inline extended', element => $header } );
             $header->add_attributes( $attr );
@@ -865,7 +880,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Header}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found a vanilla header '{green}" . $+{header_all} . "{/}' with header level '{green}" . length( $+{header_level} ) . "{/}' at pos '$pos' with capture: " . $self->dump( $re ), return => 1 } ) );
             my $text = $+{header_content};
             my $header = $top->create_header({
@@ -899,7 +915,8 @@ sub parse
         $data =~ s{$list_re}
         {
             my $list = $+{list_all};
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $list_type = $+{list_type_ordered} ? 'ol' : 'ul';
             my $re = { %- };
             # Corollary from using substr( $daata, $pos ). We ned to update the position in the string manually
@@ -930,7 +947,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtHeaderLine}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found an extended header line '{green}" . $+{header_all} . "{/}' with text '{green}" . $+{header_content} . "{/}' at pos '$pos' with capture: " . $self->dump( $re ), return => 1 } ) );
             my $text = $+{header_content};
             my $raw  = $+{header_all};
@@ -948,8 +966,8 @@ sub parse
             });
             $header->add_attributes( $attr );
     
-            ## Further process the text capture
-            ## If there are any elements, they will be placed inside the header element as children
+            # Further process the text capture
+            # If there are any elements, they will be placed inside the header element as children
             my $id = $self->document->add_object( $header );
             $self->parse( $text, { scope => 'inline extended', element => $header } );
             "${PH_PREFIX}${id}${PH_SUFFIX}\n";
@@ -964,7 +982,8 @@ sub parse
         $data =~ s{$RE{Markdown}{HeaderLine}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found a vanilla header line '{green}" . $+{header_all} . "{/}' with text '{green}" . $+{header_content} . "{/}' at pos '$pos' with capture: " . $self->dump( $re ), return => 1 } ) );
             my $text = $+{header_content};
             my $raw  = $+{header_all};
@@ -979,8 +998,8 @@ sub parse
                 pos => $pos,
                 raw => $raw,
             });
-            ## Further process the text capture
-            ## If there are any elements, they will be placed inside the header element as children
+            # Further process the text capture
+            # If there are any elements, they will be placed inside the header element as children
             $self->parse( $text, { scope => $self->scope_inline, element => $header } );
             my $id = $self->document->add_object( $header );
             "${PH_PREFIX}${id}${PH_SUFFIX}\n";
@@ -1003,7 +1022,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Line}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found new horizontal line at pos '$pos': '{green}" . $+{line_all} . "'{/} with capture: " . $self->dump( $re ), return => 1 } ) );
             my $id = $self->document->add_object( $top->create_line({
                 pos => $pos,
@@ -1019,7 +1039,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Paragraph}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $text = $+{para_all};
             my $raw  = $+{para_all};
             my $trailing_nl = $self->_total_trailing_new_lines( $text );
@@ -1047,7 +1068,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtLink}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $raw = $+{link_all};
             my $id  = $+{link_id};
             my $name = $+{link_name};
@@ -1098,7 +1120,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Link}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $raw = $+{link_all};
             my $id  = $+{link_id};
             my $name = $+{link_name};
@@ -1109,12 +1132,12 @@ sub parse
                 raw => $raw,
             });
             my $object_id = $self->document->add_object( $link );
-            ## An url has been provided, we sub-parse the link name for inline markdown, and especially abbreviations
+            # An url has been provided, we sub-parse the link name for inline markdown, and especially abbreviations
             if( $url )
             {
                 $link->url( $url );
             }
-            ## as in [Example][] instead of [Example][site_id]
+            # as in [Example][] instead of [Example][site_id]
             else
             {
                 $id = $name if( !length( $id ) );
@@ -1144,10 +1167,11 @@ sub parse
         $data =~ s{$RE{Markdown}{LinkAuto}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $raw = $+{link_all};
             my $url = $+{link_url};
-            ## Add the mailto: scheme if it's an e-mail address and the scheme is missing
+            # Add the mailto: scheme if it's an e-mail address and the scheme is missing
             substr( $url, 0, 0 ) = 'mailto:' if( length( $+{link_mailto} ) && substr( $+{link_mailto}, 0, 7 ) ne 'mailto:' );
             my $link = $top->create_link({
                 encrypt => $self->encrypt_email,
@@ -1172,7 +1196,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtImage}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $raw = $+{img_all};
             my $url = $+{img_url};
             my $id  = $+{img_id};
@@ -1210,7 +1235,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Image}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $raw = $+{img_all};
             my $url = $+{img_url};
             my $id  = $+{img_id};
@@ -1247,7 +1273,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Bold}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $content = $+{bold_text};
             my $bold = $top->create_bold({
                 pos => pos( $data ),
@@ -1266,7 +1293,8 @@ sub parse
         $data =~ s{$RE{Markdown}{Em}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $em = $top->create_em({
                 pos => $pos,
                 raw => $+{em_all},
@@ -1286,7 +1314,8 @@ sub parse
         $data =~ s{$RE{Markdown}{CodeSpan}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $raw = $+{code_all};
             my $content = $+{code_content};
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found an inline code '$raw' at pos '$pos' with content:\n'{green}" . $content . "{/}' and with capture: " . $self->dump( $re ), return => 1 } ) );
@@ -1314,7 +1343,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtCheckbox}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $check = $top->create_checkbox({
                 checked => lc( $+{check_content} ) eq 'x',
                 raw => $+{check_all},
@@ -1332,7 +1362,8 @@ sub parse
         {
             my $re = { %- };
             my $raw = $+{katex_all};
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             ## There is at least one new line, so this is a block, we use paragraph
             my $id;
             if( index( $raw, "\n" ) != -1 )
@@ -1366,7 +1397,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtStrikeThrough}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $text = $+{strike_content};
             my $strike = $top->create_strikethrough({
                 raw => $+{strike_all},
@@ -1387,7 +1419,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtInsertion}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $text = $+{ins_content};
             my $ins = $top->create_insertion({
                 raw => $+{ins_all},
@@ -1408,7 +1441,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtSubscript}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $text = $+{sub_text};
             my $sub = $top->create_subscript({
                 raw => $+{sub_all},
@@ -1429,7 +1463,8 @@ sub parse
         $data =~ s{$RE{Markdown}{ExtSuperscript}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             my $text = $+{sup_text};
             my $sup = $top->create_superscript({
                 raw => $+{sup_all},
@@ -1450,7 +1485,8 @@ sub parse
         $data =~ s{$RE{Markdown}{LineBreak}}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             $self->message_colour( 3, $self->whereami( \$data, $pos, { text => "Found a {green}line break{/} (end of line followed by 2 or more spaces) at pos '" . $pos . "' with capture: " . $self->dump( $re ), return => 1 } ) );
             my $id = $self->document->add_object( $top->create_new_line({
                 break => 1,
@@ -1464,7 +1500,8 @@ sub parse
     $data =~ s{(?<fn_backref>[ ]+\!{2}FN\!{2})}
     {
         my $re = { %- };
-        my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+        # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+        my $pos = pos( $data );
         my $id = $self->document->add_object( $top->create_text({
             pos => $pos,
             text => $+{fn_backref},
@@ -1479,7 +1516,8 @@ sub parse
         $data =~ s{\b(?<abbr_name>$abbr_re)\b}
         {
             my $re = { %- };
-            my $pos = pos( $data ) - substr( $data, $-[0], $+[0] - $-[0] );
+            # my $pos = pos( $data ) - length( substr( $data, $-[0], $+[0] - $-[0] ) );
+            my $pos = pos( $data );
             ## We save what we caught to put it back in case the abbreviation lookup failed
             my $catch = substr( $data, $-[0], $+[0] - $-[0] );
             if( defined( my $abbr = $self->document->get_abbreviation( $+{abbr_name} ) ) )
@@ -2183,7 +2221,7 @@ Markdown::Parser - Markdown Parser Only
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
